@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Mar 2002
 ;;;;
-;;;; $Id: union.lisp 10608 2005-07-01 00:39:48Z kevin $
+;;;; $Id: union.lisp 10917 2006-04-18 00:07:09Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
@@ -66,7 +66,7 @@
 	       #\A
 	       :test #'eql
 	       :fail-info "Error with union character")
-    #-(or sparc sparc-v9 mcl)
+    #-(or sparc sparc-v9 openmcl digitool)
 ;;    (util.test:test (> 0 (uffi:get-slot-value u 'tunion1 'int))
 ;;	       t
 ;;	       :fail-info
