@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: libraries.lisp 10811 2005-11-07 17:54:11Z kevin $
+;;;; $Id: libraries.lisp 10953 2006-05-17 15:14:07Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
@@ -32,7 +32,7 @@
   #-(or win32 mswindows macosx darwin ccl-5.0) '("so" "a" "o")
 )
 
-(defun find-foreign-library (names directories &key types drive-letters)  
+(defun find-foreign-library (names directories &key types drive-letters)
   "Looks for a foreign library. directories can be a single
 string or a list of strings of candidate directories. Use default
 library type if type is not specified."
@@ -53,21 +53,21 @@ library type if type is not specified."
     (dolist (name names)
       (dolist (dir directories)
 	(dolist (type types)
-	  (let ((path (make-pathname 
+	  (let ((path (make-pathname
 		       #+lispworks :host
 		       #+lispworks (when drive-letter drive-letter)
 		       #-lispworks :device
 		       #-lispworks (when drive-letter drive-letter)
-		       :name name 
+		       :name name
 		       :type type
-		       :directory 
+		       :directory
 		       (etypecase dir
 			 (pathname
 			  (pathname-directory dir))
 			 (list
 			  dir)
 			 (string
-			  (pathname-directory 
+			  (pathname-directory
 			   (parse-namestring dir)))))))
 	    (when (probe-file path)
 	      (return-from find-foreign-library path)))))))
@@ -76,7 +76,7 @@ library type if type is not specified."
 
 (defun load-foreign-library (filename &key module supporting-libraries
 					   force-load)
-  #+(or allegro mcl sbcl) (declare (ignore module supporting-libraries))
+  #+(or allegro openmcl digitool sbcl) (declare (ignore module supporting-libraries))
   #+(or cmu scl) (declare (ignore module))
   #+lispworks (declare (ignore supporting-libraries))
 
@@ -84,11 +84,11 @@ library type if type is not specified."
                           (probe-file filename)))
     (if (pathnamep filename)    ;; ensure filename is a string to check if already loaded
 	(setq filename (namestring (if (null (pathname-directory filename))
-				       filename 
+				       filename
 				       ;; lispworks treats as UNC, so use truename
 				       #+(and lispworks win32) (truename filename)
 				       #-(and lispworks win32) filename))))
-    
+
     (if (and (not force-load)
 	     (find filename *loaded-libraries* :test #'string-equal))
 	t ;; return T, but don't reload library
@@ -97,13 +97,13 @@ library type if type is not specified."
 	(let ((type (pathname-type (parse-namestring filename))))
 	  (if (string-equal type "so")
 	      (sys::load-object-file filename)
-	      (alien:load-foreign filename 
+	      (alien:load-foreign filename
 				  :libraries
 				  (convert-supporting-libraries-to-string
 				   supporting-libraries))))
 	#+scl
 	(let ((type (pathname-type (parse-namestring filename))))
-	  (alien:load-foreign filename 
+	  (alien:load-foreign filename
 			      :libraries
 			      (convert-supporting-libraries-to-string
 			       supporting-libraries)))
@@ -118,8 +118,8 @@ library type if type is not specified."
                                                 :connection-style :immediate)
 	#+allegro (load filename)
 	#+openmcl (ccl:open-shared-library filename)
-	#+(and mcl (not openmcl)) (ccl:add-to-shared-library-search-path filename t)
-	
+	#+digitool (ccl:add-to-shared-library-search-path filename t)
+
 	(push filename *loaded-libraries*)
 	t))))
 
