@@ -7,9 +7,9 @@
 ;;;; Author:        Kevin M. Rosenberg
 ;;;; Date Started:  Mar 2002
 ;;;;
-;;;; $Id: arrays.lisp 9987 2004-09-10 04:24:49Z kevin $
+;;;; $Id: arrays.lisp 10608 2005-07-01 00:39:48Z kevin $
 ;;;;
-;;;; This file, part of UFFI, is Copyright (c) 2002-2003 by Kevin M. Rosenberg
+;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
 ;;;; *************************************************************************
 
@@ -20,7 +20,7 @@
 
 (uffi:def-foreign-type long-ptr (* :long))
 
-(deftest array.1
+(deftest :array.1
     (let ((a (uffi:allocate-foreign-object :long +column-length+))
 	  (results nil))
       (dotimes (i +column-length+)
@@ -32,7 +32,7 @@
   (0 1 4 9 16 25 36 49 64 81))
 
 
-(deftest array.2
+(deftest :array.2
     (let ((a (uffi:allocate-foreign-object 'long-ptr +row-length+))
 	  (results nil))
       (dotimes (r +row-length+)
