@@ -7,9 +7,9 @@
 ;;;; Author:        Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: compress.lisp 10141 2004-11-09 02:29:43Z kevin $
+;;;; $Id: compress.lisp 10608 2005-07-01 00:39:48Z kevin $
 ;;;;
-;;;; This file, part of UFFI, is Copyright (c) 2002-2003 by Kevin M. Rosenberg
+;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
 ;;;; *************************************************************************
 
@@ -72,11 +72,11 @@
 	    (uffi:free-foreign-object destlen)
 	    (uffi:free-foreign-object dest)))))))
 
-(deftest compress.1 (compress "")
+(deftest :compress.1 (compress "")
   #(120 156 3 0 0 0 0 1) 8)
-(deftest compress.2  (compress "test")
+(deftest :compress.2  (compress "test")
   #(120 156 43 73 45 46 1 0 4 93 1 193) 12)
-(deftest compress.3 (compress "test2")
+(deftest :compress.3 (compress "test2")
   #(120 156 43 73 45 46 49 2 0 6 80 1 243) 13)
 
 (defun compress-uncompress (str)
@@ -87,6 +87,6 @@
       uncompressed)))
 
 
-(deftest uncompress.1 "" "")
-(deftest uncompress.2 "test" "test")
-(deftest uncompress.3 "test2" "test2")
+(deftest :uncompress.1 "" "")
+(deftest :uncompress.2 "test" "test")
+(deftest :uncompress.3 "test2" "test2")
