@@ -7,9 +7,9 @@
 ;;;; Author:        Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: time.lisp 10380 2005-04-04 20:31:17Z kevin $
+;;;; $Id: time.lisp 10608 2005-07-01 00:39:48Z kevin $
 ;;;;
-;;;; This file, part of UFFI, is Copyright (c) 2002 by Kevin M. Rosenberg
+;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
 ;;;; *************************************************************************
 
@@ -36,22 +36,22 @@
 
 (uffi:def-function "gmtime"
     ((time (* time-t)))
-  :returning (* tm))
+  :returning (:struct-pointer tm))
 
 (uffi:def-function "asctime"
-    ((time (* tm)))
+    ((time (:struct-pointer tm)))
   :returning :cstring)
 
 (uffi:def-type time-t :unsigned-long)
-(uffi:def-type tm-pointer (* tm))
+(uffi:def-type tm-pointer (:struct-pointer tm))
 
-(deftest time.1
+(deftest :time.1
    (uffi:with-foreign-object (time 'time-t)
      (setf (uffi:deref-pointer time :unsigned-long) 7381)
      (uffi:deref-pointer time :unsigned-long))
   7381)
 
-(deftest time.2
+(deftest :time.2
   (uffi:with-foreign-object (time 'time-t)
     (setf (uffi:deref-pointer time :unsigned-long) 7381)
     (let ((tm-ptr (the tm-pointer (gmtime time))))
@@ -86,7 +86,7 @@
 	  (uffi:get-slot-value tv 'timeval 'usecs))
        res))))
 
-(deftest timeofday.1
+(deftest :timeofday.1
     (multiple-value-bind (t1 res1) (get-utime)
       (multiple-value-bind (t2 res2) (get-utime)
 	(and (or (= t2 t1) (> t2 t1))
@@ -105,6 +105,6 @@
       (setf (uffi:deref-pointer time :unsigned-long) secs)
       (asctime (gmtime time))))))
 
-(deftest time.3
+(deftest :time.3
     (posix-time-to-asctime 0)
   "Thu Jan  1 00:00:00 1970")
